@@ -1,28 +1,40 @@
 from __future__ import annotations
 
+from sqlalchemy import or_
+
 import ckan.plugins.toolkit as tk
 
 from ckanext.toolbelt.decorators import Collector
+
 import ckanext.drupal_idp.utils as utils
 
 action, get_actions = Collector("drupal_idp").split()
 
 
-
 @action
 @tk.side_effect_free
 def user_show(context, data_dict):
-    tk.check_access('drupal_idp_user_show', dict(context), data_dict)
-    id: utils.DrupalId = tk.get_or_bust(data_dict, 'id')
-    User = context['model'].User
+    tk.check_access("drupal_idp_user_show", dict(context), data_dict)
+    id: utils.DrupalId = tk.get_or_bust(data_dict, "id")
+
+    User = context["model"].User
+
     user = (
-        context['session'].query(User.id)
-        .filter(User.plugin_extras["drupal_idp"]["id"].astext == str(id))
+        context["session"]
+        .query(User.id)
+        .filter(
+            or_(
+                User.plugin_extras["drupal_idp"]["id"].astext == str(id),
+                User.plugin_extras["drupal_idp"]["name"].astext == str(id),
+            )
+        )
         .one_or_none()
     )
+
     if user is None:
-        raise tk.ObjectNotFound(tk._(f'DrupalId({id}) not found'))
-    data_dict['id'] = user.id
+        raise tk.ObjectNotFound(tk._(f"DrupalId({id}) not found"))
+
+    data_dict["id"] = user.id
     return tk.get_action("user_show")(context, data_dict)
 
 
